# Human Action Controller (HAC)

## Goal
A human action controller running on different platforms.

| Fun      | Easy-to-use |
| -------- | --------    |
| **Accurate** | **Anywhere** |

## Fun Examples

### Controlling video
![mouse_control](https://github.com/dabit-lucas/hac/blob/main/images/mouse_control_small.gif?raw=true)

## Solutions provided by HAC
|      Platform      |      Module      | Progress | Comment |
|:------------------:|:----------------:|:--------:|:-------:|
| PC / Win10 |  Mouse Control   |    V     |         |
| PC / Win10 | Keyboard Control |    V     |         |
| PC / Ubuntu | Mouse Control |         |         |
| PC / Ubuntu | Keyboard Control |         |         |
| Switch                   |                  |          |

## Getting started

### Installation
```
$ pip install pyhac
```
### Run the demo of mouse control
```
$ git clone https://github.com/dabit-lucas/hac.git
$ cd hac
$ python demo.py
```

## Documents
[The structure of HAC](https://github.com/dabit-lucas/hac/tree/main/pyhac/README.md)

## Community
Welcome to ask any question in issues.

## Contributing
Any contribution is welcomed. Please fork this repo and summit a pull request.